# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorlib: %global perl_vendorlib %(eval "`perl -V:installvendorlib`"; echo $installvendorlib)}

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'printf "%d\\n", $Test::More::VERSION < 0.88 ? 1 : 0;' 2>/dev/null || echo 0)

# We need to test using our own copy of File::Temp if the system one is too old
%global old_file_temp %(perl -MFile::Temp -e 'printf "%d\\n", $File::Temp::VERSION < 0.20 ? 1 : 0;' 2>/dev/null || echo 0)

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%global old_eumm %(perl -MExtUtils::MakeMaker -e 'printf "%d\\n", $ExtUtils::MakeMaker::VERSION < 6.30 ? 1 : 0;' 2>/dev/null || echo 0)

Name:		perl-CPAN-Meta
Summary:	Distribution metadata for a CPAN dist
Version:	2.120530
Release:	1.%{__distinit}%{__distvers}
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/CPAN-Meta/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DA/DAGOLDEN/CPAN-Meta-%{version}.tar.gz 
Source1:	File::Temp-0.22.pm
Patch0:		CPAN-Meta-2.120530-old-eu::mm.patch
Patch1:		CPAN-Meta-2.120530-old-Test::More.patch
Patch2:		CPAN-Meta-2.120530-no-Test::Requires.patch
Patch3:		CPAN-Meta-2.120530-stopwords.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
BuildArch:	noarch
# Build
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(CPAN::Meta::YAML)
BuildRequires:	perl(JSON::PP)
BuildRequires:	perl(Parse::CPAN::Meta) >= 1.44
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(version) >= 0.82
# Test
%if %(perl -e 'print $] >= 5.008001 ? 1 : 0;')
BuildRequires:	aspell-en
%else
BuildRequires:	aspell-en-gb
%endif
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Dir)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Pod::Wordlist::hanekomu)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Pod::Coverage)
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling)
BuildRequires:	perl(Test::Version) >= 0.04
# Test::Perl::Critic only available if we have Perl 5.8.8 onwards
# Same for Test::Requires
%if %(perl -e 'print $] >= 5.008008 ? 1 : 0;')
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
BuildRequires:	perl(Test::Requires)
%endif

%description
Software distributions released to the CPAN include a META.json or, for
older distributions, META.yml, which describes the distribution, its
contents, and the requirements for building and installing the
distribution. The data structure stored in the META.json file is described
in CPAN::Meta::Spec.

%prep
%setup -q -n CPAN-Meta-%{version}

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%if %{old_eumm}
%patch0 -p1
%endif

# Patch test suite to work with old Test::More version if necessary
%if %{old_test_more}
%patch1 -p1
%endif

# Work around unavailability of Test::Requires if necessary
%if %(perl -e 'print $] >= 5.008008 ? 0 : 1;')
%patch2 -p1
%endif

# Additional words for the spell check test to ignore
%patch3 -p1

# Use our own File::Temp for testing if the system one is too old
%if %{old_file_temp}
mkdir -p testlib/File
cp -p %{SOURCE1} testlib/File/Temp.pm
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -depth -type d -exec rmdir {} \; 2>/dev/null
%{_fixperms} %{buildroot}

%check
%if %{old_file_temp}
export PERL5LIB=$(pwd)/testlib
%endif
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%files
%defattr(-,root,root,-)
%doc Changes history LICENSE README Todo
%{perl_vendorlib}/CPAN/
%{_mandir}/man3/CPAN::Meta.3pm*
%{_mandir}/man3/CPAN::Meta::Converter.3pm*
%{_mandir}/man3/CPAN::Meta::Feature.3pm*
%{_mandir}/man3/CPAN::Meta::History.3pm*
%{_mandir}/man3/CPAN::Meta::Prereqs.3pm*
%{_mandir}/man3/CPAN::Meta::Requirements.3pm*
%{_mandir}/man3/CPAN::Meta::Spec.3pm*
%{_mandir}/man3/CPAN::Meta::Validator.3pm*

%changelog
* Thu Feb 23 2012 Paul Howarth <paul@city-fan.org> - 2.120530-1
- update to 2.120530
  - dialed back perl prereq to 5.006
- add buildreqs for author tests and run the author tests:
  - aspell-en/aspell-en-gb
  - perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
  - perl(Pod::Wordlist::hanekomu)
  - perl(Test::Perl::Critic)
  - perl(Test::Requires)
  - perl(Test::Spelling)
- add patch for spell check test for words not in Fedora/RHEL dictionaries
- add patch to work around unavailability of Test::Requires on old releases
- update patches to apply cleanly

* Sat Feb  4 2012 Paul Howarth <paul@city-fan.org> - 2.120351-1
- update to 2.120351
  - work around a memory leak bug involving version objects in boolean context
- this release by DAGOLDEN -> update source URL
- drop redundant buildreq perl(Test::Requires) and patch to work around not
  having it if necessary

* Sat Dec 31 2011 Paul Howarth <paul@city-fan.org> - 2.113640-1
- update to 2.113640
  - Version::Requirements has now been merged as CPAN::Meta::Requirements,
    rendering Version::Requirements itself redundant
- this release by RJBS -> update source URL
- drop BR: perl(Version::Requirements)
- BR: perl(Test::Requires)
- don't attempt to run author tests as they fail
- update patch for building with Test::More < 0.88
- add patch for building without Test::Requires if necessary

* Mon Sep 19 2011 Paul Howarth <paul@city-fan.org> - 2.112621-1
- update to 2.112621
  - spell BACKEND environment variables correctly this time

* Mon Sep 19 2011 Paul Howarth <paul@city-fan.org> - 2.112620-1
- update to 2.112620
  - protect tests against PERL_(YAML|JSON)_BACKEND settings that could cause
    tests to fail (CPAN RT#69979)

* Sat Sep 17 2011 Paul Howarth <paul@city-fan.org> - 2.112600-1
- update to 2.112600
  - fixed spelling error in CPAN::Meta::Spec (CPAN RT#71036)

* Wed Sep 14 2011 Paul Howarth <paul@city-fan.org> - 2.112580-1
- update to 2.112580
  - use UTF-8 mode for internal structure cloning to avoid bugs in
    Perl ≤ 5.8.6 (CPAN RT#70936)
- update patches

* Wed Aug  3 2011 Paul Howarth <paul@city-fan.org> - 2.112150-1
- update to 2.112150
  - stringify any objects encountered during conversion (CPAN RT#67295)
  - fixed some broken URLs in documentation and for LGPL in legacy
    conversion (CPAN RT#68738)
  - fixed invalid private Pod in CPAN::Meta::Validator (CPAN RT#65925)
  - clarified that file paths in the 'provides' section must be in
    Unix-style (i.e. forward slashes) (CPAN RT#69045)
  - replaced examples using Module::Build::ModuleInfo with Module::Metadata
    (CPAN RT#66135)
  - new test build requirements:
    - perl(Pod::Coverage::TrustPod)
    - perl(Test::CPAN::Meta)
    - perl(Test::Pod::Coverage)
    - perl(Test::Portability::Files)
    - perl(Test::Version) ≥ 0.04
- updated patches
- drop note about CentOS 3 64-bit build failing as it seems to work now

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 2.110930-2
- rebuild for perl 5.14.1 in Rawhide
- fix dist tag for CentOS 6 and Scientific Linux

* Mon Apr  4 2011 Paul Howarth <paul@city-fan.org> - 2.110930-1
- update to 2.110930
  - the 1.x spec "gpl" and "lgpl" and "mozilla" license values now up-convert
    to "open_source" because they indicate too non-specific a license
  - fixed a bug in the 'as_string' method that checked the module version
    instead of the meta-spec version when conversion was requested
    (CPAN RT#67188)
- update patch for building with old Test::More versions
- nobody else likes macros for commands

* Mon Feb 28 2011 Paul Howarth <paul@city-fan.org> - 2.110580-1
- update to 2.110580
  - add explicit dependencies on JSON::PP and CPAN::Meta::YAML instead
    of relying on Parse::CPAN::Meta to provide them (as some CPAN Testers
    have had P::C::M installed without them somehow)
  - removed dependency on Storable as it was not a core module
    until Perl 5.8

* Fri Feb 25 2011 Paul Howarth <paul@city-fan.org> - 2.110550-1
- update to 2.110550
  - added required field 'release_status' to the synopsis of
    CPAN::Meta::Spec (CPAN RT#66118)

* Thu Feb 24 2011 Paul Howarth <paul@city-fan.org> - 2.110540-1
- update to 2.110540
  - in the presence of both 'requires' and 'build_requires', only include
    'requires' to avoid confusing some installers

* Tue Feb 15 2011 Paul Howarth <paul@city-fan.org> - 2.110440-1
- update to 2.110440
  - the as_string() method now always returns a character string; previously,
    JSON strings were UTF-8 encoded
  - the save() method now always saves with UTF-8 encoding for Perl 5.8.1 or
    greater; previously, YAML was not encoded
  - bump Parse::CPAN::Meta prereq to 1.44, as 1.43 was never released

* Thu Feb 10 2011 Paul Howarth <paul@city-fan.org> - 2.110390-1
- import from Fedora
- update to 2.110390
- drop no-longer needed BR: perl(autodie) and perl(JSON)
- add patch to support building with ExtUtils::MakeMaker < 6.31
- add patch to support building with Test::More < 0.88
- use our own copy of File::Temp if the system one is < 0.20

* Wed Dec 15 2010 Marcela Maslanova <mmaslano@redhat.com> - 2.102400-2
- rebuild to fix problems with vendorarch/lib (#661697)

* Sun Aug 29 2010 Iain Arnell <iarnell@gmail.com> 2.102400-1
- update by Fedora::App::MaintainerTools 0.006
- updating to latest GA CPAN version (2.102400)
- added a new br on perl(Carp) (version 0)
- added a new br on perl(Data::Dumper) (version 0)
- altered br on perl(ExtUtils::MakeMaker) (0 => 6.31)
- added a new br on perl(File::Spec) (version 0)
- added a new br on perl(File::Temp) (version 0.20)
- added a new br on perl(IO::Dir) (version 0)
- added a new br on perl(Scalar::Util) (version 0)
- added a new br on perl(Storable) (version 0)
- added a new br on perl(autodie) (version 0)
- added a new br on perl(version) (version 0.82)

* Thu Aug 05 2010 Iain Arnell <iarnell@gmail.com> 2.102160-1
- update to latest upstream

* Wed Jun 16 2010 Iain Arnell <iarnell@gmail.com> 2.101670-1
- update to latest upstream

* Mon Jun 14 2010 Iain Arnell <iarnell@gmail.com> 2.101610-1
- update to latest upstream

* Tue Jun 01 2010 Iain Arnell <iarnell@gmail.com> 2.101461-2
- rebuild for perl-5.12

* Fri May 28 2010 Iain Arnell <iarnell@gmail.com> 2.101461-1
- Specfile autogenerated by cpanspec 1.78.
- drop explicit requirements
